@@ -24,16 +24,17 @@ type CreateRequest struct {
 	IssueType string
 	// ParentIssueKey is required when creating a sub-task for classic project.
 	// This can also be used to attach epic for next-gen project.
-	ParentIssueKey  string
-	Summary         string
-	Body            interface{} // string in v1/v2 and adf.ADF in v3
-	Reporter        string
-	Assignee        string
-	Priority        string
-	Labels          []string
-	Components      []string
-	FixVersions     []string
-	AffectsVersions []string
+	ParentIssueKey   string
+	Summary          string
+	Body             interface{} // string in v1/v2 and adf.ADF in v3
+	Reporter         string
+	Assignee         string
+	Priority         string
+	Labels           []string
+	Components       []string
+	FixVersions      []string
+	AffectsVersions  []string
+	OriginalEstimate string
 	// EpicField is the dynamic epic field name
 	// that changes per jira installation.
 	EpicField string
@@ -215,6 +216,12 @@ func (*Client) getRequestData(req *CreateRequest) *createRequest {
 		}
 		data.Fields.M.AffectsVersions = versions
 	}
+	if req.OriginalEstimate != "" {
+		data.Fields.M.TimeTracking = &struct {
+			OriginalEstimate string `json:"originalEstimate,omitempty"`
+		}{OriginalEstimate: req.OriginalEstimate}
+	}
+
 	constructCustomFields(req.CustomFields, req.configuredCustomFields, &data)
 
 	return &data
@@ -303,6 +310,9 @@ type createFields struct {
 	AffectsVersions []struct {
 		Name string `json:"name,omitempty"`
 	} `json:"versions,omitempty"`
+	TimeTracking *struct {
+		OriginalEstimate string `json:"originalEstimate,omitempty"`
+	} `json:"timetracking,omitempty"`
 	epicField    string
 	customFields customField
 }
